<?php
namespace FM\Service;

use FM\Factory\CardsFactory;
use FM\Service\TarefaRecorrenteService;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CardsService {
    
    protected $connection;
    protected $CardsFactory;
    protected $TarefaRecorrenteService;
    protected $Environment;
    protected $newCode;
    
    public function __construct (EntityManager $entityManager, TarefaRecorrenteService $TarefaRecorrenteService, CardsFactory $CardsFactory, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->CardsFactory                 = $CardsFactory;
        $this->TarefaRecorrenteService      = $TarefaRecorrenteService;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function buscandoTipoLocal(){
        $operadores = $this->CardsFactory->buscaTipoLocal();
        return $operadores;
    }

    public function buscandoLocal(){
        $operadores = $this->CardsFactory->buscaLocal();
        return $operadores;
    }

    public function getItensChecklist(){
        return $this->CardsFactory->getItensChecklist();
    }

    public function buscandoChecklist(){
        $operadores = $this->CardsFactory->buscaChecklist();
        return $operadores;
    }

    public function buscandoItensChecklist($parametro){
        $param = array(
            "NRCHECKLIST"   => $parametro['checklist']
        );
        $operadores = $this->CardsFactory->buscaItensChecklist($param);
        return $operadores;
    }

    public function buscandoFuncionario(){
        $operadores = $this->CardsFactory->buscaFuncionario();
        return $operadores;
    }
    
    public function buscandoSupervisor(){
        $operadores = $this->CardsFactory->buscandoSupervisor();
        return $operadores;
    }

    public function buscandoFuncionarioDataSource(){
        $operadores = $this->CardsFactory->buscaFuncionarioDataSource();
        return $operadores;
    }
    
    public function buscandoSupervisorDataSource(){
        $operadores = $this->CardsFactory->buscandoSupervisorDataSource();
        return $operadores;
    }

    public function getCriterios(){
        $operadores = $this->CardsFactory->getCriterios();
        return $operadores;
    }

    public function buscandoCriterioTarefa($parametro){
        $param = array(
            "NRCHECKLIST"   => implode(',', $parametro)
        );
        $operadores = $this->CardsFactory->buscaCriterioTarefa($param);
        return $operadores;
    }

    public function buscandoTarefa($parametro){
        $param = array(
            "NRATIVIDADE"   => implode(',', $parametro['checklist'])
        );
        $operadores = $this->CardsFactory->buscaTarefa($param);

        return $operadores;
    }
    
    public function buscandoCriterioAtividade($param){
        $params = array(
            "NRCHECKLIST" => $param['NRCHECKLIST'],
            "NRATIVIDADECHK" => implode(',', $param['NRATIVIDADECHK']),
            "NRTAREFACHK" => implode(',', $param['NRTAREFACHK'])
        );
        if ($params['NRATIVIDADECHK'] < 1 || $params['NRTAREFACHK'] < 1 ) {
            return [];
        }
        $operadores = $this->CardsFactory->buscaCriterioAtividade($params);
        $retorno = array();
        $valida = array();
        forEach($operadores as $value){
            if(!(in_array($value['DSCRITERIOTAREFA'],$valida))){
                $valida[] = $value['DSCRITERIOTAREFA'];
                $retorno[] = $value;
            }
        }
        return $retorno;
    }
    
    /* public function buscandoCard($param){
        $filtrar = "";
        if($this->Environment->getCdOperador() != null){
            $filtrar = " OR FCM_CHECKLISTAGEND.CDOPERINCLUSAO = ".$this->Environment->getCdOperador();
        }
        
        $operadores = $this->CardsFactory->buscaCard(array(
            "NRFUNCIONARIO" => implode(',', $param["HIERARQ"])
        ), $filtrar);

        // --------------------------------------------------Here
        $resposta = [];
        
        forEach($operadores as $dados){
            $pos = array_search($dados['NRCHECKLISTAGEND'], array_column($resposta, 'NRCHECKLISTAGEND'));
            if(gettype($pos) == "boolean"){
                $resposta[] = array(
                    "NRCHECKLISTAGEND" => $dados["NRCHECKLISTAGEND"],
                    "NMCHECKLISTAGEND" => $dados["NMCHECKLISTAGEND"],
                    "DTHORAAGEND" => $dados["DTHORAAGEND"],
                    "DTHRFINALAGEND" => $dados["DTHRFINALAGEND"],
                    "NRLOCALCLIENTE" => $dados["NRLOCALCLIENTE"],
                    "NMLOCALCLIENTE" => $dados["NMLOCALCLIENTE"],
                    "NRLOCALCLIENTEPAI" => $dados["NRLOCALCLIENTEPAI"],
                    "NMLOCALCLIENTEPAI" => $dados["NMLOCALCLIENTEPAI"],
                    "NRTIPOLOCALCLI" => $dados["NRTIPOLOCALCLI"],
                    "NMTIPOLOCALCLI" => $dados["NMTIPOLOCALCLI"],
                    "NRCHECKLIST" => [$dados["NRCHECKLIST"]],
                    "NRTAREFA" => [$dados["NRTAREFA"]],
                    "NRATIVIDADE" => [$dados["NRATIVIDADE"]],
                    "NRESCOPOSTAREFA" => [$dados["NRESCOPOSTAREFA"]],
                    "NRATIVIDADECHK" => [$dados["NRATIVIDADECHK"]],
                    "NRCRITERIOTAREFA" => [$dados["NRCRITERIOTAREFA"]],
                    "NRFUNCIONARIO" => $dados["NRFUNCIONARIO"],
                    "NMFUNCIONARIO" => $dados["NMFUNCIONARIO"],
                    "NRENCARREGADO" => $dados["NRENCARREGADO"],
                    "NMENCARREGADO" => $dados["NMENCARREGADO"],
                    "NRGERENCIAMENTOCHK" => $dados["NRGERENCIAMENTOCHK"],
                    "NMIDSITUACAOAGEND" => $dados["NMIDSITUACAOAGEND"],
                    "NRTAREFACHK" => [$dados["NRTAREFACHK"]]
                );
            } else {
                if(!in_array($dados["NRCHECKLIST"],$resposta[$pos]["NRCHECKLIST"])) array_push($resposta[$pos]["NRCHECKLIST"],$dados["NRCHECKLIST"]);
                if(!in_array($dados["NRTAREFA"],$resposta[$pos]["NRTAREFA"])) array_push($resposta[$pos]["NRTAREFA"],$dados["NRTAREFA"]);
                if(!in_array($dados["NRATIVIDADE"],$resposta[$pos]["NRATIVIDADE"])) array_push($resposta[$pos]["NRATIVIDADE"],$dados["NRATIVIDADE"]);
                if(!in_array($dados["NRESCOPOSTAREFA"],$resposta[$pos]["NRESCOPOSTAREFA"])) array_push($resposta[$pos]["NRESCOPOSTAREFA"],$dados["NRESCOPOSTAREFA"]);
                if(!in_array($dados["NRATIVIDADECHK"],$resposta[$pos]["NRATIVIDADECHK"])) array_push($resposta[$pos]["NRATIVIDADECHK"],$dados["NRATIVIDADECHK"]);
                if(!in_array($dados["NRCRITERIOTAREFA"],$resposta[$pos]["NRCRITERIOTAREFA"])) array_push($resposta[$pos]["NRCRITERIOTAREFA"],$dados["NRCRITERIOTAREFA"]);
                if(!in_array($dados["NRTAREFACHK"],$resposta[$pos]["NRTAREFACHK"])) array_push($resposta[$pos]["NRTAREFACHK"],$dados["NRTAREFACHK"]);
            }
        }
        
        return $resposta;
    } */
    
    public function getTarefas() {
        
        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );
        
         return $this->CardsFactory->getTarefas($params);
    }

    public function getLocaisDasTarefas() {
        return $this->CardsFactory->getLocaisDasTarefas();
    }

    public function getFuncionariosDasTarefas() {
        return $this->CardsFactory->getFuncionariosDasTarefas();
    }

    public function getChecklistDasTarefas() {
        return $this->CardsFactory->getChecklistDasTarefas();
    }

    public function getTipoLocalDasTarefas() {
        return $this->CardsFactory->getTipoLocalDasTarefas();
    }

    public function insertNovaTarefa($param){
        $this->connection->beginTransaction();
        try {
            $NRORG =  $this->Environment->getNrOrg();
            
            forEach($param['DATA'] as $dados) {
            
                $dataInicial = date_create_from_format("Y/m/d H:i",  $dados['DATAINICIAL'])->format("d/m/Y H:i");
                $dataFinal = date_create_from_format("Y/m/d H:i",  $dados['DATAFINAL'])->format("d/m/Y H:i");

                forEach($param['LOCAL'] as $local) {
                    $nrchecklistagend = $this->newCode->getCodeByTableName("FCM_CHECKLISTAGEND", $NRORG, 1, 10, true);
                    $params = array(
                        "NRCHECKLISTAGEND" => $nrchecklistagend,
                        "NMCHECKLISTAGEND" => $param['NMTAREFA'],
                        "NRLOCALCLIENTE"  => $local,
                        "NRCHECKLIST"  => $param['CHECKLIST'],
                        "NRFUNCIONARIO" => $dados['NRFUNCIONARIO'],
                        "IDSITUACAOAGEND" => 1,
                        "DTHORAAGEND" => $dataInicial, 
                        "DTHRFINALAGEND" => $dataFinal,
                        "OPERADOR" => $this->Environment->getCdOperador()
                    );
                    $this->CardsFactory->insertNovaTarefa($params);
                    
                    forEach($param['TAREFA'] as $dadosTarefa) {
                        $nrtarefaagend = $this->newCode->getCodeByTableName("FCM_TAREFAAGEND", $NRORG, 1, 10, true);
                        $params = array(
                            "NRTAREFAAGEND" => $nrtarefaagend,
                            "NRCHECKLISTAGEND" => $nrchecklistagend,
                            "NRTAREFACHK" => $dadosTarefa,
                            "NRFUNCIONARIO" => $dados['NRFUNCIONARIO'],
                            "DTHORAAGEND" => $dataInicial, 
                            "DSOBSTAREFAAGEND" => null,
                            "OPERADOR" => $this->Environment->getCdOperador(),
                            "NRTAREFARECORRENTE" => (array_key_exists('NRTAREFARECORRENTE',$param)) ? $param['NRTAREFARECORRENTE'] : null
                        );
                        
                        $this->CardsFactory->insertNovaTarefa2($params);
                        
                        forEach($param['CRITERIOS'] as $dadosCriterio){
                            $nrcriteriostaragend = $this->newCode->getCodeByTableName("FCM_CRITERIOTARAGEND", $NRORG, 1, 10, true);
                            
                            $parametros = array(
                                "NRCRITERIOTARAGEND" => $nrcriteriostaragend,
                                "NMCRITERIOTARAGEND" => $dadosCriterio['DSCRITERIOTAREFA'],
                                "NRTAREFAAGEND" => $nrtarefaagend,
                                "NRCRITERIOTAREFACHK" => ($dadosCriterio['NRCRITERIOTAREFACHK'] === $dadosCriterio['DSCRITERIOTAREFA']) ? null : $dadosCriterio['NRCRITERIOTAREFACHK'],
                                "OPERADOR" => $this->Environment->getCdOperador()
                            );

                            $this->CardsFactory->insertNovaTarefa3($parametros);
                            
                        }
                    };
                    
                    
                    if($dados["VISTORIAAUTOMATICA"]) {
                        $nrgerenciamentochk = $this->newCode->getCodeByTableName("FCM_GERENCIAMENTOCHK", $NRORG, 1, 10, true);
                        $params = array(
                            "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                            "NMGERENCIAMENTOCHK" => $param['NMTAREFA'],
                            "NRLOCALCLIENTE"  => $local,
                            "NRCHECKLIST"  => $param['CHECKLIST'],
                            "NRFUNCIONARIO" => $dados['NRENCARREGADO'],
                            "DTHORAAGEND" => $dataInicial,
                            "DTHRFINALAGEND" => $dataFinal,
                            "OPERADOR" => $this->Environment->getCdOperador(),
                            "NRCHECKLISTAGEND" => $nrchecklistagend
                        );
                        
                        
                        $this->CardsFactory->insertNovaTarefa4($params);
                        forEach($param['TAREFA'] as $dadosTarefa){
                            
                            $nrtarefaagendchk = $this->newCode->getCodeByTableName("FCM_TAREFAGERCHK", $NRORG, 1, 10, true);
                            $params = array(
                                "NRTAREFAGERCHK" => $nrtarefaagendchk,
                                "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                                "NRTAREFACHK" => $dadosTarefa,
                                "NRFUNCIONARIO" => $dados['NRFUNCIONARIO'],
                                "DTHORATAREFAGERCHK" => $dataInicial,
                                "DSOBSTAREFAGERCHK" => null,
                                "OPERADOR" => $this->Environment->getCdOperador()
                            ); 
                            $this->CardsFactory->insertNovaTarefa5($params);
                            
                            forEach($param['CRITERIOS'] as $dadosCriterio){
                                $nrcriteriostaragerchk = $this->newCode->getCodeByTableName("FCM_CRITERIOTARGERCHK", $NRORG, 1, 10, true);
                                
                                $parametros = array(
                                    "NRCRITERIOTARGERCHK" => $nrcriteriostaragerchk,
                                    "NMCRITERIOTARGERCHK" => $dadosCriterio['DSCRITERIOTAREFA'],
                                    "NRTAREFAGERCHK" => $nrtarefaagendchk,
                                    "NRCRITERIOTAREFACHK" => ($dadosCriterio['NRCRITERIOTAREFACHK'] === $dadosCriterio['DSCRITERIOTAREFA']) ? null : $dadosCriterio['NRCRITERIOTAREFACHK'],
                                    "OPERADOR" => $this->Environment->getCdOperador()
                                );
                                $this->CardsFactory->insertNovaTarefa6($parametros);
                            }
                        }
                    }
                }
            }
            
            if($param["RECORRENTE"]) {
                $this->TarefaRecorrenteService->tarefaRecorrente($param);
            }

            if (array_key_exists('NRTAREFARECORRENTE',$param)){
                $this->CardsFactory->salvarLog($param['NRTAREFARECORRENTE'], "Criado com sucesso");
            }

            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function recriarTarefasRecorrente($NRTAREFARECORRENTE = null,$inicio = null,$final = null){
        if($NRTAREFARECORRENTE != NULL){
            $datasJaCriadas = $this->TarefaRecorrenteService->getAllDatasCreate($NRTAREFARECORRENTE)[0];
        }
        $datasJaCriadas = (array_key_exists("DTHORATAREFAAGEND", $datasJaCriadas)) ? $datasJaCriadas['DTHORATAREFAAGEND']: [];
        $datasJaCriadas = explode(',', $datasJaCriadas);
        $dadosHaCriar = ($this->TarefaRecorrenteService->getTarefaRecorrente($NRTAREFARECORRENTE))['data'];
        forEach($dadosHaCriar as $dadosLinha){
            $start = ($inicio) ? $inicio : date("Y/m/01", strtotime("+1 months"));
            $fim = ($final) ? $final : date("t/m/Y", strtotime("+1 months"));
            $diasHaIncluir = [];
           
            for ($i = intval(date("d", strtotime($start))); $i <= intval(date("d", strtotime($fim))); $i++) {
                if(date("Y/m/d", strtotime($dadosLinha['DTHORAREINICIAR'])) <= $start || $NRTAREFARECORRENTE != NULL){
                    if(in_array(date('w', strtotime($start)),explode(',',$dadosLinha['DIASSEMANA'])) && !in_array($start, $datasJaCriadas)){
                        $diaComHora = date("Y/m/d H:i", strtotime($start." ".$dadosLinha["HORARIO"]));
                        $diasHaIncluir[] = array(
                            "DATAINICIAL" => $diaComHora, 
                            "DATAFINAL" => date("Y/m/d H:i", strtotime("+".$dadosLinha["DURACAO"]." Minutes", strtotime($diaComHora))),
                            "NRFUNCIONARIO" => $dadosLinha["NRFUNCTAREFA"],
                            "NRENCARREGADO" => $dadosLinha["NRFUNCVISTORIA"],
                            "VISTORIAAUTOMATICA" => ($dadosLinha["IDCRIARVISTORIA"] == 'S')
                        );
                    }
                }
                $start = date('Y/m/d', strtotime('+1 Days', strtotime($start)));
            }
            if(count($diasHaIncluir) > 0){
                $this->insertNovaTarefa(array(
                    "NRTAREFARECORRENTE" => $NRTAREFARECORRENTE,
                    "NMTAREFA" => $dadosLinha['NMTAREFA'],
                    "LOCAL" => explode(',',$dadosLinha['LOCALTAREFA']),
                    "CHECKLIST" => $dadosLinha['NRCHECKLIST'],
                    "ITENSCHECK" => explode(',',$dadosLinha['ITENSCHECKLIST']),
                    "TAREFA" => explode(',',$dadosLinha['ITENSTAREFA']),
                    "CRITERIOS" => json_decode($dadosLinha['CRITERIOS'],true),
                    "DATA" => $diasHaIncluir,
                    "RECORRENTE" => false,
                    'CDOPERADOR' => null
                ));
            }
        }
    }

    public function playTarefasRecorrente($param){
        $this->connection->beginTransaction();
        try {
            if (array_key_exists('DATAINICIAL',$param)){
                $param["DATAINICIAL"] = date("d/m/Y");
            }
            $dt = explode('/',$param["DATAINICIAL"]);
            $dataInicio = date("Y/m/d", strtotime($dt[1].'/'.$dt[0].'/'.$dt[2]));
            
            if(date("Y/m/d") >= $dataInicio){
                $this->TarefaRecorrenteService->mudarStatusTarefaRecorrente(array(
                    "TIPO" => "INICIAR",
                    "NRTAREFARECORRENTE" => $param["NRTAREFARECORRENTE"]
                ));
                $dataInicio = date("Y/m/d");
            }
            
            $REINICIO = $dataInicio;
            $final = null;
            
            if(date("Y/m/t", strtotime("+1 months")) >= $dataInicio){
                if($dataInicio < date("Y/m/25")){
                    $final = date("Y/m/t");
                    $REINICIO = date("Y/m/01", strtotime("+1 months"));
                } else {
                    $final = date("Y/m/t", strtotime("+1 months"));
                    $REINICIO = date("Y/m/01", strtotime("+2 months"));
                }
                $this->recriarTarefasRecorrente($param["NRTAREFARECORRENTE"], $dataInicio, $final);
            }
            
            $this->TarefaRecorrenteService->setreinicioTarefa(array(
                "DTHORAREINICIAR" => $REINICIO,
                "NRTAREFARECORRENTE" => $param["NRTAREFARECORRENTE"]
            ));
            
            
            $this->connection->commit();
            $response = "OK";
        }
        catch(\Exception $e) {
             $this->connection->rollback();
             $response = [utf8_decode($e->getErrorCode())];
        }
        
        return $response;
    }

    public function deletarTarefas($parametros) {
        $this->connection->beginTransaction();

        try {
            foreach ($parametros['NRCHECKLISTAGEND'] as $nr ) {
                $param = array (
                    'NRCHECKLISTAGEND' => $nr
                );

                $this->CardsFactory->deletarTarefaEVistoria($param);
            }
            $this->connection->commit();

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function updateTarefa($param){
        $this->connection->beginTransaction();
        try {
        
            $NRORG =  $this->Environment->getNrOrg();
            $dataInicial = date('Y/m/d H:i', strtotime($param['Data']." ".$param['HoraInicio']));
            $duracao = explode(':', $param['TempoMedio']);
            $dataFinal = date('Y/m/d H:i', strtotime('+'.$duracao[0].' Hour +'.$duracao[1].' Minutes',strtotime($dataInicial)));
            
            $this->CardsFactory->deletarDependenteTarefaEVistoria(array(
                    "NRCHECKLISTAGEND" => $param['NRCHECKLISTAGEND'],
                )
            );
            
            forEach($param['EditselectNomeLocal'] as $local){
                $nrchecklistagend = $param['NRCHECKLISTAGEND'];
                $params = array(
                    "NRCHECKLISTAGEND" => $nrchecklistagend,
                    "NMCHECKLISTAGEND" => $param['EditNomeTarefa'],
                    "NRLOCALCLIENTE"  => $local,
                    "NRCHECKLIST"  => $param['EditselectChecklist'],
                    "NRFUNCIONARIO" => $param['EditFuncionario'],
                    "DTHORAAGEND" => $dataInicial, 
                    "DTHRFINALAGEND" => $dataFinal,
                    "CDOPERULTATU" => $this->Environment->getCdOperador()
                );
                
                $this->CardsFactory->updateTarefa($params);
                forEach($param['EditselectTarefa'] as $dadosTarefa){
                    $nrtarefaagend = $this->newCode->getCodeByTableName("FCM_TAREFAAGEND", $NRORG, 1, 10, true);
                    $params = array(
                        "NRTAREFAAGEND" => $nrtarefaagend,
                        "NRCHECKLISTAGEND" => $nrchecklistagend,
                        "NRTAREFACHK" => $dadosTarefa,
                        "NRFUNCIONARIO" => $param['EditFuncionario'],
                        "DTHORAAGEND" => $dataInicial, 
                        "DSOBSTAREFAAGEND" => null,
                        "OPERADOR" => $this->Environment->getCdOperador()
                    );
                    
                    $operadores = $this->CardsFactory->insertNovaTarefa2($params);
                    forEach($param['EditCriterios'] as $dadosCriterio){
                        $nrcriteriostaragend = $this->newCode->getCodeByTableName("FCM_CRITERIOTARAGEND", $NRORG, 1, 10, true);
                        
                        $parametros = array(
                            "NRCRITERIOTARAGEND" => $nrcriteriostaragend,
                            "NMCRITERIOTARAGEND" => $dadosCriterio['DSCRITERIOTAREFA'],
                            "NRTAREFAAGEND" => $nrtarefaagend,
                            "NRCRITERIOTAREFACHK" => ($dadosCriterio['NRCRITERIOTAREFACHK'] === $dadosCriterio['DSCRITERIOTAREFA']) ? null : $dadosCriterio['NRCRITERIOTAREFACHK'],
                            "OPERADOR" => $this->Environment->getCdOperador()
                        );
                        $operadores = $this->CardsFactory->insertNovaTarefa3($parametros);
                        
                    }
                };
                
                if($param["NRGERENCIAMENTOCHK"] !== null) {
                    $nrgerenciamentochk = $param['NRGERENCIAMENTOCHK'];
                    $params = array(
                        "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                        "NMGERENCIAMENTOCHK" => $param['EditNomeTarefa'],
                        "NRLOCALCLIENTE"  => $local,
                        "NRCHECKLIST"  => $param['EditselectChecklist'],
                        "NRFUNCIONARIO" => $param['EditFuncionarioVistoria'],
                        "DTHORAAGEND" => $dataInicial,
                        "DTHRFINALAGEND" => $dataFinal,
                        "OPERADOR" => $this->Environment->getCdOperador(),
                        "NRCHECKLISTAGEND" => $nrchecklistagend
                    );
                    
                    
                    $operadores = $this->CardsFactory->updateVistoria($params);
                    forEach($param['EditselectTarefa'] as $dadosTarefa){
                        
                        $nrtarefaagendchk = $this->newCode->getCodeByTableName("FCM_TAREFAGERCHK", $NRORG, 1, 10, true);
                        $params = array(
                            "NRTAREFAGERCHK" => $nrtarefaagendchk,
                            "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                            "NRTAREFACHK" => $dadosTarefa,
                            "NRFUNCIONARIO" => $param['EditFuncionario'],
                            "DTHORATAREFAGERCHK" => $dataInicial,
                            "DSOBSTAREFAGERCHK" => null,
                            "OPERADOR" => $this->Environment->getCdOperador()
                        );
                       $operadores = $this->CardsFactory->insertNovaTarefa5($params);
                        forEach($param['EditCriterios'] as $dadosCriterio){
                            $nrcriteriostaragerchk = $this->newCode->getCodeByTableName("FCM_CRITERIOTARGERCHK", $NRORG, 1, 10, true);
                            
                            $parametros = array(
                                "NRCRITERIOTARGERCHK" => $nrcriteriostaragerchk,
                                "NMCRITERIOTARGERCHK" => $dadosCriterio['DSCRITERIOTAREFA'],
                                "NRTAREFAGERCHK" => $nrtarefaagendchk,
                                "NRCRITERIOTAREFACHK" => ($dadosCriterio['NRCRITERIOTAREFACHK'] === $dadosCriterio['DSCRITERIOTAREFA']) ? null : $dadosCriterio['NRCRITERIOTAREFACHK'],
                                "OPERADOR" => $this->Environment->getCdOperador()
                            );
                            $operadores = $this->CardsFactory->insertNovaTarefa6($parametros);
                        }
                    }
                }
            }
            $this->connection->commit();
            $response = ["OK"];
        }
        catch(\Exception $e) {
             $this->connection->rollback();
             $response = [utf8_decode($e->getErrorCode())];
             $response = [$e];
        }
        
        return $response;
    }
}
?>