/* eslint-disable no-console */
/* eslint-disable */
import {
  Metadata, IDictionary, Router,
  IEventParam, Http, Loader, Config,
} from '@zeedhi/core';
import {
  Col, Tabs, Button, IComponentRender, TextInput, Modal, ModalService,
  TreeGrid, Card, Text, Image, DialogService, AlertService,
} from '@zeedhi/common';
import { IterableComponentRender, CardTitle } from '@zeedhi/teknisa-components-common';
import { VUE_APP_BASE_URL } from '../router';

export class GerenciarLocaisController {
  private modalMap!: Modal;

  // Instancias de controllers
  public localAtendimento = Loader.getInstance('LocalAtendimentoController');

  public qrCodeController = Loader.getInstance('QRCodeController');

  public qrCodeModalController = Loader.getInstance('ModalQRCodeController');

  public locationIdToDelete: number | string = 0;

  public gridIdToInstance: number = 0;

  public locationChildren: IDictionary = [];

  // Verifica qual o acesso e altera a exibição dos botões de "novo local" e "editar"
  public isVisibleElement: boolean = !(localStorage.getItem('idpermissslocais') === 'V');

  // Coleção para filtro
  public dataFilter: IDictionary = {
    inputLocalAt: '',
    inputLocal: '',
  };

  public tabActive({ component }: any) {
    component.activeTab = Number('1' == localStorage.getItem("AbaAtiva"))
    localStorage.removeItem("AbaAtiva");
  }

  // Muda o label do button Novo local para Novo tipo de local, quando se muda de aba
  public changeButton() {
    const tabObject = Metadata.getInstance<Tabs>('tabs');
    const buttonObject = Metadata.getInstance<Button>('button_newLocal');

    if (tabObject.activeTab === 0) {
      buttonObject.label = 'Novo Local';
      buttonObject.to = '/localAtendimento';
    }
    if (tabObject.activeTab === 1) {
      buttonObject.label = 'Novo Tipo de Local';
      buttonObject.to = '/tipoLocal/null';
    }
  }

  // Busca os locais do tipo agrupamento completo e seta no card do iterable
  public async getCompleteGroupingLocation({ component }: any) {
    await Http.post('/getUnities', this.dataFilter).then((response: IDictionary) => {
      component.datasource.updateData( response.data.dataset.options);
    });
  }

 // Quando expandir o collapse o component filho TreeGrid é montado e então atualiza o data do grid
  public async updateGridData({ component }: { component:TreeGrid }) {
    const locationId = Number(component.name.substr(14));
    const childrenArray: IDictionary[] = await this.localAtendimento.mountLocationChildrenArray(locationId); // Traz o array de filhos
    component.datasource.updateData(childrenArray);
  }

  public verificaTipoLocal({ row }:any) {
    return row.locationTypeId !== '3' && this.isVisibleElement;
  }

  // Filtro
  public filterInputLocalAt() {
    const tabObject = Metadata.getInstance<Tabs>('tabs');
    const searchObject = Metadata.getInstance<TextInput>('textSearch');

    if (tabObject.activeTab === 0) { // Aqui seria o filtro para a primeira tab
      // this.dataFilter.inputLocalAt = searchObject.value;
      // this.setUnities();
    } else {
      this.dataFilter.inputLocal = searchObject.value;
      this.setLocalType();
    }
  }

  // Chama a rota /agrupamentoSimples para o ID do agrupamento simples do card clicado
  public changeRouteAS(nr: number) {
    Router.replace(`/agrupamentoSimples/${nr}`);
  }

   // Chama a tela de edição de local de atendimento
  public changeRouteToEdit({ component }: { component:Button }) {
    const gridInstanceId = Number((component.name.substr(15)).split('_')[0]);
    const gridObject = Metadata.getInstance<TreeGrid>(`locationsGrid-${gridInstanceId}`);
    setTimeout(() => {
      const dadosHaSalvar = gridObject.datasource.currentRow.original.original;
      dadosHaSalvar['setLocalCli'] = true;
      this.setDadosToEdit('edit', JSON.stringify(dadosHaSalvar));
    }, 100);
  }

  public editLocalSuperior({ component }:any){
    const iterable = Metadata.getInstance<IterableComponentRender>('LocationsIterable').datasource.data.filter((elemento: any) => elemento.NRLOCALCLIENTE === Number(component.name.split('-')[1]));
    iterable[0]['setLocalCli'] = true;
    iterable[0]['IDTIPOLOCALCLI'] = (iterable[0].NRLOCALCLIENTEPAI === null) ? '1' : ((iterable[0].NRLOCALCLIENTEPAI === '1') ? '2' : '3');
    this.setDadosToEdit('edit', JSON.stringify(iterable[0]));
  }

   // Abre a tela de novo local de atendimento com um pai pré selecionado
  public setParentLocalToAdd({ component }: { component:Button }) {
    const gridInstanceId = Number((component.name.substr(12)).split('_')[0]);
    const gridObject = Metadata.getInstance<TreeGrid>(`locationsGrid-${gridInstanceId}`);
    setTimeout(() => {
      const dadosHaSalvar = gridObject.datasource.currentRow.original.original;
      this.setDadosToEdit('add', JSON.stringify({
        NRLOCALCLIENTEPAI: dadosHaSalvar.NRLOCALCLIENTE,
        CDCLIENTE: dadosHaSalvar.CDCLIENTE,
      }));
    }, 100);
  }

  public setParentLocalToAddCG({ component }:any){
    const iterable = Metadata.getInstance<IterableComponentRender>('LocationsIterable').datasource.data.filter((elemento: any) => elemento.NRLOCALCLIENTE === Number(component.name.split('-')[1]));
    this.setDadosToEdit('add', JSON.stringify({
      NRLOCALCLIENTEPAI: iterable[0].NRLOCALCLIENTE,
      CDCLIENTE: iterable[0].CDCLIENTE,
    }));
  }

  public setDadosToEdit(rota: string, dados: string) {
    window.localStorage.setItem('dadosToEdit', dados);
    Router.replace(`/localAtendimento/${rota}`);
  }

  // Gera o QRCode dado um id do local
  public async generateQRCode(locationId: number) {
    // const baseLink = VUE_APP_BASE_URL;
    // const sourceLink = `${baseLink}/${locationId}`;
    Metadata.getInstance<Image>('qRCodeImage').src = await this.qrCodeController.generateQRCode(locationId);
  }

  // Abre o modal com o QRcode
  public openQRCodeModal({ component }: { component:Button }) {
    Promise.all([this.qrCodeModalController.openQRCodeModal()]).then(() => {
      const gridInstanceId = Number((component.name.substr(15)).split('_')[0]);
      const gridObject = Metadata.getInstance<TreeGrid>(`locationsGrid-${gridInstanceId}`);
      this.generateQRCode(gridObject.datasource.currentRow.value);
      Metadata.getInstance<CardTitle>('titleQrcode').subtitle = gridObject.datasource.currentRow.name;
      Metadata.getInstance<Text>('locationType').text = gridObject.datasource.currentRow.locationType;
    });
  }

  // Fecha o modal com o QRcode
  public closeQRCodeModal() {
    Promise.all([this.qrCodeModalController.closeQRCodeModal()]).then(() => {
    });
  }

  // Altera a visibilidade do QRCode quando na linha tenha um local do tipo 'local de atendimento(id=3)'
  public setQRCodeVisibility({ row }: any) {
    return (row.locationTypeId === '3');
  }

  public async deleteLocation() {
    this.mountLocationChildrenArray();
    const emptyArray: IDictionary[] = [];
    if(this.locationChildren[1] === "") {
      this.locationChildren.splice(1,1); // Caso o local seja o do collapase, o segundo elemento viria vazio, logo, aqui ele será retirado
    }

    Http.post('/deleteLocation', { locationsList: this.locationChildren }).then((response: IDictionary) => {
      if(response.data.dataset.info.message === 'Deletado com sucesso') {
        AlertService.show({
          name: 'confirmDelete',
          text: 'Local(s) deletado(s) com sucesso.',
          color: 'success',
          top: true,
          left: false,
        });
        const iterable = Metadata.getInstance<IterableComponentRender>('LocationsIterable');
        iterable.datasource.updateData(emptyArray);
        this.getCompleteGroupingLocation({ component: iterable});
      } else {
        DialogService.show({
          name: 'errorDialogLocal',
          type: 'error',
          title: 'Erro!',
          text: 'Não foi possível deletar local(s).',
        });
      }
    })
  }

  // Deleta a partir de um local de dentro do grid
  public deleteInsideGrid({ component }: { component:Button }) {
    this.locationChildren = [];
    const gridId = Number((component.name.substr(15)).split('_')[0]);
    setTimeout(() => {
      const gridObject = Metadata.getInstance<TreeGrid>(`locationsGrid-${gridId}`);
      this.locationIdToDelete = gridObject.datasource.currentRow.value; //delay pra dar tempo da rota estar clicada
    }, 100);
    this.gridIdToInstance = gridId;
    this.confirmLocationDelete();
  }

  // Deleta a partir do local do header do collapse Card
  public deleteInsideCollapseHeader({ component }: { component:Button }) {
    this.locationChildren = [];
    const gridId = Number(component.name.substr(15));
    this.locationChildren.push(gridId); // o id do local a ser deletado está presente no name do grid, por isso o nome gridId
    this.locationIdToDelete = ''; // inicialmente, para popular o data do grid, teve q se retirar todos os parentId daqueles filhos diretos do local do header do collapse, logo essa linha serve para que a verificação futura seja válida
    this.gridIdToInstance = gridId;
    this.confirmLocationDelete();
  }

  // Caixa de confirmação de delete
  public confirmLocationDelete() {
    DialogService.show({
      name: 'locationDelete',
      type: 'warning',
      title: 'Excluir Local!',
      text: 'Todas as informações deste local serão perdidas. Deseja continuar?',
      buttons: [
        {
          name: 'yes',
          component: 'ZdButton',
          label: 'Sim',
          events: this.deleteLocationEvents,
          outline: true,
        },
        {
          name: 'no',
          component: 'ZdButton',
          label: 'Não',
          events: this.cancelDeleteEvents,
        },
      ],
    });
  }

    // Direciona para o evento de delete
  private deleteLocationEvents: any = {
    click: () => {
      this.deleteLocation();
      DialogService.hide();
    },
  };

  // Fecha a caixa de diálogo
  private cancelDeleteEvents: any = {
    click: () => {
      DialogService.hide();
    },
  };

  // monta o array de locais a serem excluídos
  public mountLocationChildrenArray() {
    const locationId = this.locationIdToDelete;

    this.gatherLocationChildren(locationId);
  }

  // Salva num array os filhos a partir do local de agrupamento completo
  public gatherLocationChildren(locationId: any) {
    this.locationChildren.push(locationId);
    const treeGrid = Metadata.getInstance<TreeGrid>(`locationsGrid-${this.gridIdToInstance}`);

    treeGrid.datasource.data.forEach((location: any) => {
      if (locationId === location.parentId) {
        this.gatherLocationChildren(location.value);
      }
    });
  }


  /*  --------- Tab: Tipos de Local ----------  */

  public cardLocalType(nm: string, nr: number, code: number, tipo: string) {
    return {
      name: '',
      component: 'ZdCard',
      width: 'auto',
      cssClass: 'zd-mb-3',
      hover: true,
      children: [
        {
          name: `row${nr}`,
          component: 'ZdRow',
          children: [
            {
              name: '',
              component: 'ZdText',
              text: 'mdi-office-building',
              tag: 'v-icon',
              isVisible: false,
            },
            {
              name: '',
              component: 'ZdCol',
              cssClass: 'text-start',
              sm: 2,
              children: [
                {
                  name: '',
                  component: 'ZdText',
                  text: `${nm}`,
                  cssClass: 'color-title-card',
                  style: {
                    'font-weight': 'bold',
                  },
                },
              ],
            },
            {
              name: '',
              component: 'ZdCol',
              sm: 6,
              children: [
                {
                  name: '',
                  component: 'ZdText',
                  text: `${tipo}`,
                  style: {
                    color: '#6c757d',
                  },
                },
              ],
            },
            {
              name: '',
              component: 'ZdCol',
              sm: 3,
              cssClass: 'zd-ml-12 text-end',
              children: [
                {
                  name: `btn${nr}`,
                  component: 'ZdButton',
                  iconName: 'mdi-pencil',
                  icon: true,
                  small: true,
                  to: `/tipoLocal/${nr}`,
                  isVisible: this.isVisibleElement,
                },
              ],
            },
          ],
        },
      ],
    };
  }

  // requisição de Tipos de local
  public setLocalType() {
    const colObject = Metadata.getInstance<Col>('localTypesCol');
    colObject.children = [];
    Http.post('/getGLocalType', this.dataFilter).then((response: IDictionary) => {
      response.data.dataset.options.forEach((dados: IDictionary) => {
        colObject.children.push(this.cardLocalType(dados.NMTIPOLOCALCLI, dados.NRTIPOLOCALCLI, dados.IDTIPOLOCALCLI, dados.TIPOLOCAL) as IComponentRender);
      });
    });
  }

  public padraoCod(){
    Http.get('paramMascara').then((response: any) => {
      window.localStorage.setItem('padraoMascara', JSON.stringify(response.data[0]));
    })
  }

  public async createmodalMap({ component }: any) {
    this.modalMap = await ModalService.create({
      name: 'modalMap',
      children: [
        {
          name: 'fromTypescriptHeader',
          component: 'ZdHeader',
          color: 'transparent',
          cssClass: 'header-left-size',
          padless: true,
          elevation: 0,
          leftSlot: [
            {
              name: 'titleText',
              component: 'ZdText',
              text: 'Localização',
            },
          ],
          rightSlot: [
            {
              name: 'closeModalButton',
              component: 'ZdModalCloseButton',
              small: true,
              modalName: 'modalMap',
            },
          ],
        },
        {
          name: `form_${component.parent.children[1].text}`,
          component: 'ZdTag',
          tag: 'div',
          id: 'map',
          events: {
            onCreated: '{{GerenciarLocaisController.addScript}}',
          }
        },
      ],
    });
    this.modalMap.show();
  }

  public async closemodalMap() {
    await this.modalMap.hide();
    this.modalMap?.destroy();
  }

  public addScript({ component }: any) {
    const scriptFunction = document.createElement('script');
    scriptFunction.innerHTML  = `
      let map, infoWindow;

      function initMap() {
        map = new google.maps.Map(document.getElementById("map"), {
          center: { lat: -19.912998, lng: -43.940933 },
          zoom: 6,
        });
        // infoWindow = new google.maps.InfoWindow();
      
        // const locationButton = document.createElement("button");
      
        // locationButton.textContent = "${component.name.split('_')[1]}";
        // locationButton.classList.add("custom-map-control-button");
        // map.controls[google.maps.ControlPosition.TOP_CENTER].push(locationButton);
        // locationButton.addEventListener("click", () => {
        //   // Try HTML5 geolocation.
        //   if (navigator.geolocation) {
        //     navigator.geolocation.getCurrentPosition(
        //       (position) => {
        //         const pos = {
        //           lat: position.coords.latitude,
        //           lng: position.coords.longitude,
        //         };
      
        //         infoWindow.setPosition(pos);
        //         infoWindow.setContent("Location found.");
        //         infoWindow.open(map);
        //         map.setCenter(pos);
        //       },
        //       () => {
        //         handleLocationError(true, infoWindow, map.getCenter());
        //       }
        //     );
        //   } else {
        //     // Browser doesn't support Geolocation
        //     handleLocationError(false, infoWindow, map.getCenter());
        //   }
        // });
      }
      
      function handleLocationError(browserHasGeolocation, infoWindow, pos) {
        infoWindow.setPosition(pos);
        infoWindow.setContent(
          browserHasGeolocation
            ? "Error: The Geolocation service failed."
            : "Error: Your browser doesn't support geolocation."
        );
        infoWindow.open(map);
      }
    `;
    
    document.body.appendChild(scriptFunction);
    
    const script = document.createElement('script');
    script.type = 'text/javascript';
    script.src = `https://maps.googleapis.com/maps/api/js?key=${Config.env.apiGoogle}&callback=initMap&v=weekly`;
    script.async = true;
    
    document.body.appendChild(script);
  }
}
